import { ComponentInterface, EventEmitter } from '../stencil-public-runtime';
import { SuperTabsConfig } from '../interface';
export declare class SuperTabsToolbarComponent implements ComponentInterface {
    el: HTMLSuperTabsToolbarElement;
    /** @internal */
    config?: SuperTabsConfig;
    /**
     * Whether to show the indicator. Defaults to `true`
     */
    showIndicator: boolean;
    /**
     * Background color. Defaults to `'primary'`
     */
    color: string | undefined;
    /**
     * Whether the toolbar is scrollable. Defaults to `false`.
     */
    scrollable: boolean;
    /**
     * If scrollable is set to true, there will be an added padding
     * to the left of the buttons.
     *
     * Setting this property to false will remove that padding.
     *
     * The padding is also configurable via a CSS variable.
     */
    scrollablePadding: boolean;
    /**
     * Emits an event when a button is clicked
     * Event data contains the clicked SuperTabButton component
     */
    buttonClick: EventEmitter<HTMLSuperTabButtonElement>;
    buttons: HTMLSuperTabButtonElement[];
    width: number;
    offsetLeft: number;
    /**
     * Current indicator position.
     * This value is undefined until the component is fully initialized.
     * @private
     */
    private indicatorPosition;
    /**
     * Current indicator width.
     * This value is undefined until the component is fully initialized.
     * @private
     */
    private indicatorWidth;
    /**
     * Reference to the current active button
     * @private
     */
    private activeButton?;
    private activeTabIndex;
    private indicatorEl;
    private buttonsContainerEl;
    private initialCoords?;
    private lastPosX;
    private touchStartTs;
    private lastClickTs;
    private isDragging;
    private leftThreshold;
    private rightThreshold;
    private slot;
    private hostCls;
    componentDidLoad(): Promise<void>;
    componentWillUpdate(): void;
    componentDidRender(): void;
    private updateWidth;
    /** @internal */
    setActiveTab(index: number, align?: boolean, animate?: boolean): Promise<void>;
    /** @internal */
    setSelectedTab(index: number, animate?: boolean): Promise<void>;
    /** @internal */
    moveContainer(scrollX: number, animate?: boolean): Promise<void>;
    private getButtonFromEv;
    onClick(ev: any): void;
    private onButtonClick;
    onTouchStart(ev: TouchEvent): Promise<void>;
    onTouchMove(ev: TouchEvent): Promise<void>;
    onTouchEnd(ev: TouchEvent): Promise<void>;
    onColorUpdate(): Promise<void>;
    private setHostCls;
    private onSlotChange;
    private queryButtons;
    private updateThresholds;
    private markButtonActive;
    private setButtonsContainerEl;
    private adjustContainerScroll;
    /**
     * Align the indicator with the selected button.
     * This will adjust the width and the position of the indicator element.
     * @param index {number} the active tab index
     * @param [animate] {boolean=false} whether to animate the transition
     */
    private alignIndicator;
    /**
     * Internal method to output values in debug mode.
     */
    private debug;
    render(): any;
}
